unofficial mirror of meta@public-inbox.org
 help / color / mirror / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH] www: make mirror instructions more prominent
Date: Tue,  8 Sep 2020 08:29:14 +0000	[thread overview]
Message-ID: <20200908082914.452-1-e@80x24.org> (raw)

In order to fight the misconception that public-inboxes are
centralized, anchor "#mirror" to the clone instructions and
place an emphasis on "mirror", not just cloning.

While we're at it, better describe multi-epoch -V2 inboxes,
since some users do not seem to realize epochs consist of
different data.
---
 lib/PublicInbox/WwwStream.pm | 37 ++++++++++++++++++++++--------------
 1 file changed, 23 insertions(+), 14 deletions(-)

diff --git a/lib/PublicInbox/WwwStream.pm b/lib/PublicInbox/WwwStream.pm
index e06e3456..f1b5119a 100644
--- a/lib/PublicInbox/WwwStream.pm
+++ b/lib/PublicInbox/WwwStream.pm
@@ -50,9 +50,10 @@ sub html_top ($) {
 	} elsif ($ctx->{qp}->{t}) {
 		$top = qq(<a\nhref="./">$top</a>);
 	}
-	my $links = "<a\nhref=\"$help\">help</a> / ".
-			"<a\nhref=\"$color\">color</a> / ".
-			"<a\nhref=\"$atom\">Atom feed</a>";
+	my $links = qq(<a\nhref="$help">help</a> / ).
+			qq(<a\nhref="$color">color</a> / ).
+			qq(<a\nhref=#mirror>mirror</a> / ).
+			q(<a\nhref="$atom">Atom feed</a>);
 	if ($ibx->search) {
 		my $q_val = delete($ctx->{-q_value_html}) // '';
 		$q_val = qq(\nvalue="$q_val") if $q_val ne '';
@@ -83,7 +84,11 @@ sub code_footer ($) {
 
 sub _html_end {
 	my ($ctx) = @_;
-	my $urls = 'Archives are clonable:';
+	my $urls = <<EOF;
+<a
+id=mirror>This inbox may be cloned and mirrored by anyone:</a>
+EOF
+
 	my $ibx = $ctx->{-inbox};
 	my $desc = ascii_html($ibx->description);
 
@@ -94,12 +99,18 @@ sub _html_end {
 	my %seen = ($http => 1);
 	if (defined($max)) { # v2
 		for my $i (0..$max) {
 			# old parts my be deleted:
 			-d "$ibx->{inboxdir}/git/$i.git" or next;
 			my $url = "$http/$i";
 			$seen{$url} = 1;
 			push @urls, "$url $dir/git/$i.git";
 		}
+		my $nr = scalar(@urls);
+		if ($nr > 1) {
+			$urls .= "\n\t# this inbox consists of $nr epochs:";
+			$urls[0] .= "\t# oldest";
+			$urls[-1] .= "\t# newest";
+		}
 	} else { # v1
 		push @urls, $http;
 	}
@@ -111,12 +122,7 @@ sub _html_end {
 		push @urls, $u =~ /\Ahttps?:/ ? qq(<a\nhref="$u">$u</a>) : $u;
 	}
 
-	if (defined($max) || scalar(@urls) > 1) {
-		$urls .= "\n" .
-			join("\n", map { "\tgit clone --mirror $_" } @urls);
-	} else {
-		$urls .= " git clone --mirror $urls[0]";
-	}
+	$urls .= "\n" .  join("\n", map { "\tgit clone --mirror $_" } @urls);
 	if (defined $max) {
 		my $addrs = $ibx->{address};
 		$addrs = join(' ', @$addrs) if ref($addrs) eq 'ARRAY';
@@ -134,16 +140,19 @@ EOF
 	}
 
 	my $cfg_link = ($ctx->{-upfx} // '').'_/text/config/raw';
-	$urls .= qq(\nExample <a\nhref="$cfg_link">config snippet</a> for mirrors\n);
+	$urls .= <<EOF;
+
+Example <a
+href="$cfg_link">config snippet</a> for mirrors.
+EOF
 	my @nntp = map { qq(<a\nhref="$_">$_</a>) } @{$ibx->nntp_url};
 	if (@nntp) {
-		$urls .= "\n";
 		$urls .= @nntp == 1 ? 'Newsgroup' : 'Newsgroups are';
 		$urls .= ' available over NNTP:';
 		$urls .= "\n\t" . join("\n\t", @nntp) . "\n";
 	}
 	if ($urls =~ m!\b[^:]+://\w+\.onion/!) {
-		$urls .= "\n note: .onion URLs require Tor: ";
+		$urls .= " note: .onion URLs require Tor: ";
 		$urls .= qq[<a\nhref="$TOR_URL">$TOR_URL</a>];
 	}
 	'<hr><pre>'.join("\n\n",
@@ -94,12 +99,18 @@ sub _html_end {
 	if (defined($max)) { # v2
 		for my $i (0..$max) {
-			# old parts my be deleted:
+			# old epochs my be deleted:
 			-d "$ibx->{inboxdir}/git/$i.git" or next;
 			my $url = "$http/$i";

                 reply	other threads:[~2020-09-08  8:29 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200908082914.452-1-e@80x24.org \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).